/************************************************************************
*	Copyright (c) 1997-2002 California Institute of Technology      *
*                     U.S. Government Sponsorship                       *
* Under contract with the National Aeronautics and Space Administration *
*************************************************************************/


#define _NBNULL_DATA_

#ifndef _BASELINE_
#include "baseline.h"
#endif

class NBNulldata
{
private:
  // Elements for data storage
  char *starName;
  int starNum;
  int month,day,year,nChannels;
  int frameRate;
  double jd,ut,delay,longDelay;
  double *lambda,*flux,*nullLeakage,*nullLeakageError;
  baseline *baselinePtr;



public:
  // Required elements for the linked-list code
  NBNulldata *nextNode;
  double sortKey;


  // Constructor
  NBNulldata(const char *star_name,const int star_num,
	 const int Month,const int Day,const int Year,
	 const double JD,const double UT,const double Delay,
	 const double LongDelay,const int NChannels,
	 double *Lambda,double *Flux,
	 double *NullLeakage,double *NullLeakageError,
	 const baseline *bLine)
  {
    starName = strdup(star_name);
    starNum = (int) star_num;
    month = (int) Month;
    day = (int) Day;
    year = (int) Year;
    jd = (double) JD;
    ut = (double) UT;
    delay = (double) Delay;
    longDelay = (double) LongDelay;
    nChannels = (int) NChannels;
    lambda = Lambda;
    flux = Flux;
    nullLeakage = NullLeakage;
    nullLeakageError = NullLeakageError;
    baselinePtr = (baseline *) bLine;
  }

  // Destructor
  ~NBNulldata(void)
  {
    if (starName)
      delete starName;

    if (nChannels)
      {
	if (lambda)
	  delete lambda;
	if (flux)
	  delete flux;
	if (nullLeakage)
	  delete nullLeakage;
	if (nullLeakageError)
	  delete nullLeakageError;
      } // end nChannels check
  } // end NBNull destructor

  // Accessor Member Functions
  char *get_starName(void) {return starName;}
  int get_starNum(void) {return starNum;}
  int get_month(void) {return month;}
  int get_day(void) {return day;}
  int get_year(void) {return year;}
  double get_jd(void) {return jd;}
  double get_ut(void) {return ut;}
  double get_delay(void) {return delay;}
  double get_longDelay(void) {return longDelay;}
  int get_nChannels(void) {return nChannels;}
  double get_lambda(const int channel) {return lambda[channel];}
  double get_flux(const int channel) {return flux[channel];}
  double get_nullLeak(const int channel) {return nullLeakage[channel];}
  double get_nullSigma(const int channel) {return nullLeakageError[channel];}
  baseline *get_baseline(void) {return baselinePtr;}

};

  
