/************************************************************************
*	Copyright (c) 1997-2002 California Institute of Technology      *
*                     U.S. Government Sponsorship                       *
* Under contract with the National Aeronautics and Space Administration *
*************************************************************************/


#define _NB_DATA_

#ifndef _BASELINE_
#include "baseline.h"
#endif

class NBdata
{
private:
  // Elements for data storage
  char *starName, *cameraName;
  int starNum;
  int month,day,year,nChannels;
  double frameRate;
  double jd,ut,delay,longDelay,jitter;
  double *lambda,*nPhot,*v2c,*v2i,*ratio;
  baseline *baselinePtr;



public:
  // Required elements for the linked-list code
  NBdata *nextNode;
  double sortKey;


  // Constructor
  NBdata(const char *star_name,const int star_num,
	 const int Month,const int Day,const int Year,
	 const double JD,const double UT,const double Delay,
	 const double LongDelay, const double Jitter,
	 const int NChannels,double *Lambda,double *NPhot,
	 double *V2c,double *V2i,double *Ratio,double FrameRate,
//jsh test 1203
	 const baseline *bLine, const char *camera_name)
// const baseline *bLine)
  {
    starName = strdup(star_name);
    starNum = (int) star_num;
    month = (int) Month;
    day = (int) Day;
    year = (int) Year;
    jd = (double) JD;
    ut = (double) UT;
    delay = (double) Delay;
    longDelay = (double) LongDelay;
    jitter = (double) Jitter;
    nChannels = (int) NChannels;
    lambda = Lambda;
    nPhot = NPhot;
    v2c = V2c;
    v2i = V2i;
    ratio = Ratio;
    frameRate = FrameRate;
    baselinePtr = (baseline *) bLine;
    cameraName = strdup(camera_name);
  }

  // Destructor
  ~NBdata(void)
  {
    if (starName)
      delete starName;
    if (cameraName)
      delete cameraName;

    if (nChannels)
      {
	if (lambda)
	  delete lambda;
	if (nPhot)
	  delete nPhot;
	if (v2c)
	  delete v2c;
	if (v2i)
	  delete v2i;
	if (ratio)
	  delete ratio;
      } // end nChannels check
  } // end NB destructor

  // Accessor Member Functions
  char *get_starName(void) {return starName;}
  char *get_cameraName(void) {return cameraName;}
  int get_starNum(void) {return starNum;}
  int get_month(void) {return month;}
  int get_day(void) {return day;}
  int get_year(void) {return year;}
  double get_jd(void) {return jd;}
  double get_ut(void) {return ut;}
  double get_delay(void) {return delay;}
  double get_longDelay(void) {return longDelay;}
  int get_nChannels(void) {return nChannels;}
  double get_lambda(const int channel) {return lambda[channel];}
  double get_nPhot(const int channel) {return nPhot[channel];}
  double get_v2c(const int channel) {return v2c[channel];}
  double get_v2i(const int channel) {return v2i[channel];}
  double get_ratio(const int channel) {return ratio[channel];}
  double get_frameRate(void) {return frameRate;}
  baseline *get_baseline(void) {return baselinePtr;}

};

  
