/************************************************************************
*	Copyright (c) 1997-2001 California Institute of Technology      *
*                     U.S. Government Sponsorship                       *
* Under contract with the National Aeronautics and Space Administration *
*************************************************************************/


#define _DATA_LIST_

#define NULL_NODE 0

#define INSERT_HEAD 9
#define INSERT_HERE 99
#define INSERT_SORT  999
#define APPEND  9999

/*
 dataNode -- prototype for the atomic record structure.  This class
 MUST provide:
  * fields for a nextNode pointer and sortKey
  * accessor functions to its data members
  *  declare dataList as a friend class to allow the linked list code
  *   to manipulate the sortKey and nextNode pointer values

*/

/*

class dataNode
{
private:
  dataNode *nextNode;
  float sortKey;

public:
  dataNode(newdata);
  ~dataNode(newdata);


  friend class dataList;
};
*/

 //#include <iostream>
 //using namespace std;

// dataList -- template for the single linked-list structure
template <class dataNode>
class dataList
{
private:
  int nodeCount;
  dataNode *head;
  dataNode *current;

public:
  // Constructor
  dataList(void) {nodeCount = 0; head = NULL_NODE;}

  // Destructor
  ~dataList(void)
  {
    /**********  local declarations data_list destructor  *******************/
    dataNode *p = head, *q;

    /**********  begin data_list destructor  ********************************/
    while (p != NULL_NODE)
      {
	q = p;
	p = p->nextNode;
	delete q;
      }
    head = NULL_NODE;
    nodeCount = 0;
    /**********  end data_list destructor  **********************************/
  }



  // Iterator
  int iterate(void)
  {
    /**********  local declarations iterate  ********************************/
    int iteration = 0;

    /**********  begin iterate  *********************************************/
    if ((current != NULL_NODE) && (current->nextNode != NULL_NODE))
      {
	//cout << "StarList->iterate()  current[" << current << "]  next[" << current->nextNode << "]" << endl;

	current = current->nextNode;
	iteration = 1;
      }

    return iteration;
    /**********  end iterate  ***********************************************/
  }

  // end-of-list check
  int endOfList(void)
    {
      if ((current == NULL) || (current->nextNode == NULL))
	return 1;
      else
	return 0;
    }

  // Insert/append a node in/to the list
  void insert(dataNode *newData,
	      const double sKey,
	      const int append = APPEND)
  {
    /**********  begin insert  **********************************************/
    // Set the sort key field in newData
    newData->sortKey = sKey;

    /* Link newData in... */

    /* If this is the first insertion, modify the head pointer */
    if (head == NULL_NODE)
      {
	head = current = newData;
	newData->nextNode = NULL_NODE;
      }
    else /* Otherwise, link it in at the desired location, depending on append */
      {
	switch (append)
	  {
	    // Inserting at the head of the list
	  case INSERT_HEAD : 
	    {
	      newData->nextNode = head;
	      head = current = newData;
	      break;
	    }

	  // Inserting at the current pointer location
	  case INSERT_HERE :
	    {
	      if (current = NULL_NODE)
		current = head;
	      newData->nextNode = current->nextNode;
	      current->nextNode = newData;
	      break;
	    }

	  // Insertion sort based on the value of the sort key
	  case INSERT_SORT :
	    {
	      if ((head->sortKey) > newData->sortKey)
		{
		  newData->nextNode = head;
		  head = newData;
		}
	      else // regular intsertion sort
		{
		  if ((current == NULL_NODE) || (current->sortKey > newData->sortKey))
		    current = head;
		  while ((current != NULL_NODE) && (current->nextNode != NULL_NODE)
			 && ((current->nextNode->sortKey) < newData->sortKey))
		    current = current->nextNode;
		  newData->nextNode = current->nextNode;
		  current->nextNode = newData;
		}
	      break;
	    }

	  // Appending to the end of the list
	  case APPEND :
	    {
	      if (current != NULL_NODE)
		current = head;
	      while ((current != NULL_NODE) && (current->nextNode != NULL_NODE))
		current = current->nextNode;
	      newData->nextNode = current->nextNode;
	      current->nextNode = newData;
	    }
	  } // end insert-mode switch
      } // end subsequent node link-in

    // Finally, increment the node count
    nodeCount++;

    /**********  end insert  ************************************************/
  }

  // Pop to the head of the list
  void gotoHead(void) {current = head;}

  // Retrieve pointers to the constituent pieces
  int numberNodes(void) {return nodeCount;}
  dataNode *getHead(void) {return head;}
  dataNode *getCurrent(void) {return current;}
  
  // possibility to totally screw up your list and leak memory
  int resetCurrent(dataNode* n) { if(n != NULL) { current = n; return 1; } return 0; }
};

