/************************************************************************
*	Copyright (c) 1997-2001 California Institute of Technology      *
*                     U.S. Government Sponsorship                       *
* Under contract with the National Aeronautics and Space Administration *
*************************************************************************/

#include <config.h>

#include <stdio.h>
#include <string.h>

#include "NBNulldata.h"
#include "dataList.h"
#include "nbNullStarList.h"


/************************************************************************
*  StarList destructor -- local to StarList.cc (A.B. 1/17/96)		*
*									*
*  A.  Purpose:	The StarList destructor performs the cleanup of the     *
*       star list.                                                      *
*									*
*  B.  Background and use:						*
*									*
*  C.  Called by:							*
*									*
*  D.  Input/output files:						*
*									*
*  E.  Parameter description:						*
*	Input -								*
*	Output -							*
*									*
*  F.  Detail function description:					*
*	      1.  Local Functions:					*
*	      2.  Externals:						*
*	      3.  Globals and Nonlocals used:				*
*	      4.  Global and Nonlocal variables modified:		*
*	      5.  Function flow is as follows:				*
*	      6.  Functions called by					*
*									*
*  G.  Function value: This function returns no useable value.		*
*									*
*************************************************************************/
/**********  function declaration StarList destructor  ***************/
StarList::~StarList(void)
{
/**********  local declarations StarList destructor  *****************/
  StarNode *p = head, *q;

/**********  begin StarList destructor  ******************************/
  while (p != NULL)
    {
      q = p;
      p = p->nextNode;
      delete q->starData;
      delete q;
    }
  head = NULL_NODE;
  nodeCount = 0;
/**********  end StarList destructor  **********************************/
}


/************************************************************************
*  star list iterator -- local to data_list.cc (A.B. 3/7/96).		*
*									*
*  A.  Purpose:	The function iterate moves the current list pointer	*
*       down the list (so long as this is possible).			*
*									*
*  B.  Background and use:						*
*									*
*  C.  Called by:							*
*									*
*  D.  Input/output files:						*
*									*
*  E.  Parameter description:						*
*	Input -								*
*	Output -							*
*									*
*  F.  Detail function description:					*
*	      1.  Local Functions:					*
*	      2.  Externals:						*
*	      3.  Globals and Nonlocals used:				*
*	      4.  Global and Nonlocal variables modified:		*
*	      5.  Function flow is as follows:				*
*	      6.  Functions called by					*
*									*
*  G.  Function value: This function returns a one (1) if the iteration *
*       was successful, and a zero (0) otherwise (int).        		*
*									*
*************************************************************************/
/**********  function declaration iterate  ******************************/
int StarList::iterate(void)
{
/**********  local declarations iterate  ********************************/
  int iteration = 0;

/**********  begin iterate  *********************************************/
  if ((current != NULL_NODE) && (current->nextNode != NULL_NODE))
    {
      current = current->nextNode;
      iteration = 1;
    }
  return iteration;
/**********  end iterate  ***********************************************/
}


/************************************************************************
*  star list insert -- local to data_list.cc (A.B. 3/7/96)	        *
*									*
*  A.  Purpose:	The function insert creates and inserts a data data     *
*       node in the linked list.					*
*									*
*  B.  Background and use:						*
*									*
*  C.  Called by:							*
*									*
*  D.  Input/output files:						*
*									*
*  E.  Parameter description:						*
*	Input -								*
*	Output -							*
*									*
*  F.  Detail function description:					*
*	      1.  Local Functions:					*
*	      2.  Externals:						*
*	      3.  Globals and Nonlocals used:				*
*	      4.  Global and Nonlocal variables modified:		*
*	      5.  Function flow is as follows:				*
*	      6.  Functions called by					*
*									*
*  G.  Function value: This function returns no useable value.		*
*									*
*************************************************************************/
/**********  function declaration insert  *******************************/
void StarList::insert(const char *star_name,const int append)
{
/**********  begin insert  **********************************************/
  /* Create and fill the new node with its constituent pointers... */
  StarNode *tmp = new StarNode;
  tmp->starName = strdup(star_name);
  tmp->starNum = 0;
  tmp->starData = new dataList<NBNulldata>();

  /* Link it in... */
  /* If this is the first insertion, modify the head pointer */
  if (head == NULL)
    {
      head = current = tmp;
      tmp->nextNode = NULL_NODE;
    }
  else /* Otherwise, link it in at the current location */
    {
      if (append) /* Or at the end as requested. */
	  while ((current != NULL_NODE) && (current->nextNode != NULL_NODE))
	    current = current->nextNode;
      tmp->nextNode = current->nextNode;
      current->nextNode = tmp;
      current = tmp;
    }

  /* Increment the node count */
  nodeCount++;

/**********  end insert  ************************************************/
}


/************************************************************************
*  star list insert -- local to data_list.cc (A.B. 3/7/96)	        *
*									*
*  A.  Purpose:	The function insert creates and inserts a data data     *
*       node in the linked list.					*
*									*
*  B.  Background and use:						*
*									*
*  C.  Called by:							*
*									*
*  D.  Input/output files:						*
*									*
*  E.  Parameter description:						*
*	Input -								*
*	Output -							*
*									*
*  F.  Detail function description:					*
*	      1.  Local Functions:					*
*	      2.  Externals:						*
*	      3.  Globals and Nonlocals used:				*
*	      4.  Global and Nonlocal variables modified:		*
*	      5.  Function flow is as follows:				*
*	      6.  Functions called by					*
*									*
*  G.  Function value: This function returns no useable value.		*
*									*
*************************************************************************/
/**********  function declaration insert  *******************************/
void StarList::insert(const int star_num,const int append)
{
/**********  begin insert  **********************************************/
  /* Create and fill the new node with its constituent pointers... */
  StarNode *tmp = new StarNode;
  tmp->starName = (char *) NULL;
  tmp->starNum = star_num;
  tmp->starData = new dataList<NBNulldata>();

  /* Link it in... */
  /* If this is the first insertion, modify the head pointer */
  if (head == NULL)
    {
      head = current = tmp;
      tmp->nextNode = NULL;
    }
  else /* Otherwise, link it in at the current location */
    {
      if (append) /* Or at the end as requested. */
	  while ((current != NULL) && (current->nextNode != NULL))
	    current = current->nextNode;
      tmp->nextNode = current->nextNode;
      current->nextNode = tmp;
      current = tmp;
    }

  /* Increment the node count */
  nodeCount++;

/**********  end insert  ************************************************/
}


/************************************************************************
*  findStar -- local to StarList.cc (A.B. 9/22/97)			*
*									*
*  A.  Purpose:	This version of findStar sets the working StarList      *
*       pointer to the star dataList for the input character star       *
*       name.  It returns a one (1) if this operation has been          *
*       successful, and a zero (0) otherwise.				*
*									*
*  B.  Background and use:						*
*									*
*  C.  Called by:							*
*									*
*  D.  Input/output files:						*
*									*
*  E.  Parameter description:						*
*	Input -								*
*	Output -							*
*									*
*  F.  Detail function description:					*
*	      1.  Local Functions:					*
*	      2.  Externals:						*
*	      3.  Globals and Nonlocals used:				*
*	      4.  Global and Nonlocal variables modified:		*
*	      5.  Function flow is as follows:				*
*	      6.  Functions called by					*
*									*
*  G.  Function value: This function returns a one (1) if this          *
*       operation has been * successful, and a zero (0) otherwise       *
*       (integer).                                                      *
*									*
*************************************************************************/
/**********  function declaration find_star  ****************************/
int StarList::findStar(const char *star_name)
{
/**********  begin find_star  *******************************************/
  /* Go to the head of the current list */
  current = head;
  while (current != NULL_NODE)
    {
      if (strcasecmp(star_name,current->starName) == 0)  // Bug fix AB 6/03
	return 1;                                        // changed from strncasecmp (see wbCalib equiv)
      else
	current = current->nextNode;
    }
  current = head;
  return 0;
/**********  end find_star  *********************************************/
}


/************************************************************************
*  find_star -- local to data_list.cc (A.B. 9/22/97)			*
*									*
*  A.  Purpose:	This version of find_star sets the working StarList    *
*       pointer to the star data list for the input integer star        *
*	number.  It returns a one (1) if this operation has been        *
*       successful, and a zero (0) otherwise.				*
*									*
*  B.  Background and use:						*
*									*
*  C.  Called by:							*
*									*
*  D.  Input/output files:						*
*									*
*  E.  Parameter description:						*
*	Input -								*
*	Output -							*
*									*
*  F.  Detail function description:					*
*	      1.  Local Functions:					*
*	      2.  Externals:						*
*	      3.  Globals and Nonlocals used:				*
*	      4.  Global and Nonlocal variables modified:		*
*	      5.  Function flow is as follows:				*
*	      6.  Functions called by					*
*									*
*  G.  Function value: This function returns a one (1) if this          *
*       operation has been * successful, and a zero (0) otherwise       *
*       (integer).                                                      *
*									*
*************************************************************************/
/**********  function declaration find_star  ****************************/
int StarList::findStar(const int nstar)
{
/**********  begin find_star  *******************************************/
  /* Go to the head of the current list */
  current = head;
  while (current != NULL)
    {
      if (current->starNum == nstar)
	return 1;
      else
	current = current->nextNode;
    }
  current = head;
  return 0;
/**********  end find_star  *********************************************/
}
