/************************************************************************
*	Copyright (c) 1997-2001 California Institute of Technology      *
*                     U.S. Government Sponsorship                       *
* Under contract with the National Aeronautics and Space Administration *
*************************************************************************/

#ifndef _NB_DATA_
#include "NBdata.h"
#endif

#ifndef _DATA_LIST_
#include "dataList.h"
#endif


class StarNode
{
private:
  StarNode *nextNode;

  char *starName;
  int starNum;
  dataList<NBdata> *starData;

  friend class StarList;
};


class StarList
{
private:
  int nodeCount;
  StarNode *head;
  StarNode *current;

public:
  /* Constructor and destructor */
  StarList(void) {nodeCount = 0; head = NULL_NODE;}
  ~StarList(void);

  /* Iterator */
  int iterate(void);
       

  /* Insert/append a node in/to the list */
  void insert(const char *star_name,const int append = 1);
  void insert(const int star_num,const int append = 1);

  /* Pop to the head of the list */
  void gotoHead(void) {current = head;}

  /* Retrieve the data for a particular star */
  int findStar(const char *star_name);
  int findStar(const int nstar);

  /* Retrieve (pointers to) the constituent pieces */
  int numberNodes(void) {return nodeCount;}
  char *getStarName(void) {return current->starName;}
  int getStarNumber(void) {return current->starNum;}

  dataList<NBdata> *getStarData(void) {return current->starData;}

  StarNode *getCurrent(void) { return current; }
};

