#########################################################################
#        Michelson Science Center (MSC) -- http://msc.caltech.edu       #
#	Copyright (c) 2003-2004 California Institute of Technology      #
#                     U.S. Government Sponsorship                       #
# Under contract with the National Aeronautics and Space Administration #
#########################################################################
# updated for V2Calib packaging/build 3/05

sub SumplotCmdOptions
{
  my $cmdOpts;

  if($hc) {
    $cmdOpts .= " -hc";
  } # end hardcopy

  if($plotAll) {
    $cmdOpts .= " -all";
  }
  if($plotOne) {
    $cmdOpts .= " -one";
  }
  if($gif) {
    $cmdOpts .= " -gif";
  }
  if($png) {
    $cmdOpts .= " -png";
  }
  if($pointsize) {
    $cmdOpts .= " -pointsize $pointsize";
  }
  if($font) {
    $cmdOpts .= " -font $font";
  }
  if($size) {
    $cmdOpts .= " -size $size";
  }
  if($scale) {
    $cmdOpts .= " -scale $scale";
  }


  return $cmdOpts;
} # end SumplotCmdOptions


sub doXYPlot {
#  my @args = @;
  my $datafile = shift @_;
  my $lim1_l = shift @_;
  my $lim1_h = shift @_;
  my $lim2_l = shift @_;
  my $lim2_h = shift @_;

  print "plot ";
  ## do plot limits
  print "[$lim1_l:$lim1_h][$lim2_l:$lim2_h] ";
  #my $x = shift @_;
  #my $y = shift @_;
  #my $key = shift @_;
  my $cmdstr = shift @_;
  #print "'$datafile' u $x:$y t '$key'";
  print "'$datafile' $cmdstr";
  while($cmdstr = shift @_) {
    print ", \\\n '$datafile' $cmdstr";
  }
  print "\n";
}

sub doPlot
{
  my @args = @_;

  open(STARS,$args[0]) || die "Error: can't find starlist $args[0]\n";

  print "plot ";
  if($args[3]) {
    ## do plot limits
    print "[$args[4]:$args[5]][$args[6]:$args[7]] ";
  } else {
    print "[*:*][*:*] ";
  }

  while (my $line = <STARS>) {
    chomp($line);
    if($args[8]) { #print error bars
       print "'$line' u $args[1]:$args[2]:$args[8] ";
# had to move this down below so it appears AFTER the title
#       print "w err ";
    }
    else {
       print "'$line' u $args[1]:$args[2] ";
    }
    my @tmp = split /\./, $line;
    print "t ' $tmp[1]'";  # add title
    if($args[8]) { #add err AFTER the title
       print "w err ";
    }
    if(!(eof(STARS))) {
      print ", \\\n";
    } else {
      print "\n";
    }
  }

  close(STARS);
}

sub doPlot2
{
  # args = starList, x1, y1, x2, y2
  my @args = @_;

  open(STARS,$args[0]) || die "Error: can't find starlist $args[0]\n";
  print "plot ";
  print "[*:*][*:*] ";

  while (my $line = <STARS>) {
    chomp($line);
    print "'$line' u $args[1]:$args[2] ";
    my @tmp = split /\./, $line;
    print "t ' $tmp[1]-K1',";
    print "'$line' u $args[3]:$args[4] ";
    @tmp = split /\./, $line;
    print "t ' $tmp[1]-K2'";
    if(!(eof(STARS))) {
      print ", \\\n";
    } else {
      print "\n";
    }
  }

  close(STARS);
}

sub doPlotScale
{
  # args = starList, x1, y1, scale  - limits are auto-set
  my @args = @_;

  open(STARS,$args[0]) || die "Error: can't find starlist $args[0]\n";

  print "plot ";
  print "[*:*][*:*] ";

  while (my $line = <STARS>) {
    chomp($line);
    print "'$line' u $args[1]:(\$ $args[2]*$args[3]) ";
    my @tmp = split /\./, $line;
    print "t ' $tmp[1]'";
    if(!(eof(STARS))) {
      print ", \\\n";
    } else {
      print "\n";
    }
  }

  close(STARS);
}

sub doPlotAdd
{
  # args = starList, x1, y1, y1a  - limits are auto-set
  my @args = @_;

  open(STARS,$args[0]) || die "Error: can't find starlist $args[0]\n";

  print "plot ";
  print "[*:*][*:*] ";

  while(my $line = <STARS>) {
    chomp($line);
    print "'$line' u $args[1]:(\$ $args[2] + \$ $args[3]) ";
    my @tmp = split /\./, $line;
    print "t ' $tmp[1]'";
    if(!(eof(STARS))) {
      print ", \\\n";
    } else {
      print "\n";
    }
  }

  close(STARS);
}

sub doPlotSubtract
{
  # args = starList, x1, y1, y1a  - limits are auto-set
  my @args = @_;

  open(STARS,$args[0]) || die "Error: can't find starlist $args[0]\n";

  print "plot ";
  print "[*:*][*:*] ";

  while (my $line = <STARS>) {
    chomp($line);
    print "'$line' u $args[1]:(\$ $args[2] - \$ $args[3]) ";
    my @tmp = split /\./, $line;
    print "t ' $tmp[1]'";
    if (!(eof(STARS))) {
      print ", \\\n";
    } else {
      print "\n";
    }
  }

  close(STARS);
}

sub NoDataPlot
{
    print "set nolog y \n";
    print "set xrange [0:1] \n";
    print "set yrange [0:1] \n";
    print "set label \"No Data Found\" at 0.4,0.5 \n";
    print "plot 0 \n";
    print "set xrange [*:*] \n";
    print "set yrange [*:*] \n";
    return 1;
}

# check for NULL values for both log & non-log plots
sub NullCheck
{
  my ($ancList, $column) = @_;

  open(LIST,"$ancList");
  my @fileList = <LIST>;
  close(LIST);

  my $FoundNonNull = -1;
  foreach my $filename (@fileList) {
    open(ANC,"$filename") || die "Error: can't find $filename\n";
    while (<ANC>) {
      my @fields = split;
      if($fields[$column-1] ne "NULL") {
        $FoundNonNull = 1;
      }
    }
    close(ANC);
  }
  return $FoundNonNull;
}

# checks for NULL or negative values for log plots
sub NullNegativeCheck
{
  my ($sumList, $column, $isFile) = @_;

  my @fileList;
  if($isFile eq 0) {
     open(LIST,"$sumList");
     @fileList = <LIST>;
     close(LIST);
  }
  else {
     @fileList = $sumList;
  }

  my $FoundNonNeg = -1;
  foreach my $filename (@fileList) {
    open(SUM,"$filename") || die "Error: can't find $filename\n";
    while (<SUM>) {
      my @fields = split;
      if(($fields[$column-1] ne "NULL") && ($fields[$column-1] > 0.0)) {
        $FoundNonNeg = 1;
      }
    }
    close(SUM);
  }
  return $FoundNonNeg;
}


sub hitReturn
{
  my ($hc, $gif, $png) = @_;
  if(!$hc && !$gif && !$png) {
    print "pause -1 'Hit return to continue'\n\n";
  } else {
    print "\n";
  }
}


# plot n points
sub doPlotN
{
  # args = datafile, x1, y1, l1, x2, y2, l2, ...
  my @args = @_;

  open(STARS,$args[0]) || die "Error: can't find starlist $args[0]\n";
  print "plot [*:*][*:*] \\\n";

  while (my $line = <STARS>) {
    chomp($line);
    for (my $idx = 1; $idx < $#args; $idx += 3) {
        print "\t'$line' u $args[$idx+0]:$args[$idx+1] ";
        my @tmp = split /\./, $line;
        print "t ' $tmp[1]$args[$idx+2]'";
        print ", \\\n" if $idx < $#args - 3;
    }
    if(!(eof(STARS))) {
      print ", \\\n";
    } else {
      print "\n";
    }
  }

  close(STARS);
}


# plot n points with error bars
sub doPlotNError
{
  # args = datafile, x1, y1, error1, l1, x2, y2, error2, l2 ...
  my @args = @_;

  open(STARS,$args[0]) || die "Error: can't find starlist $args[0]\n";
  print "plot [*:*][*:*] \\\n";

  while (my $line = <STARS>) {
    chomp($line);
    for (my $idx = 1; $idx < $#args; $idx += 4) {
        print "\t'$line' u $args[$idx+0]:$args[$idx+1]:$args[$idx+2] ";
        my @tmp = split /\./, $line;
        print "t ' $tmp[1]$args[$idx+3]' w err";
        print ", \\\n" if $idx < $#args - 4;
    }
    if(!(eof(STARS))) {
      print ", \\\n";
    } else {
      print "\n";
    }
  }

  close(STARS);
}




# this file is 'required', so return truth
return 1;
