#define _KI_H_


#ifndef _ANGLES_
#include "angles.h"
#endif


#ifndef VECTORS_H
#include "Vector.h"
#endif



// Define some geometrical "constants" for KI

// Global geometry
// Keck is at 19 49.6  N    155 28.4 W
// (http://www2.keck.hawaii.edu:3636/realpublic/observing/kecktelgde/ktelgde-1.html)
#define KI_LONGITUDE (-155.473333 * DEG_TO_RAD)    // radians
#define KI_LATITUDE (+19.826667 * DEG_TO_RAD)      // radians
#define KI_ALTITUDE 4123.0                         // meters

// Earth-ref vector for the location of PTI
static Vector KI_er(KI_LONGITUDE,KI_LATITUDE);

// Baseline Information

// Local KI_S1S2 Baseline (m)
//  x = site East, y = site North, z = site Up.
static Vector KI_Baseline_S1S2(12.37,16.23,0.01);

// KI_S1S2 Baseline bias term (m) from parameter file (mod 9/12/02
// because Rachel bent me to her will...)
#define KI_S1S2_DELAY_BIAS -20.58  


// KI_K1K2 Baseline Information  (March 14, 2001 solution)
// static Vector KI_Baseline_K1K2(51.703989,67.455287,0.001524);
// Mod 12/2/02 -- A.B.  Composite from solutions from Oct and Nov runs
// static Vector KI_Baseline_K1K2(51.701838,67.454586,-0.002236);
//#define KI_K1K2_DELAY_BIAS +40.0
//#define KI_K1K2_DELAY_BIAS -1.41
//  (mod 9/12/02 because Rachel bent me to her will...)
// #define KI_K1K2_DELAY_BIAS +40.39
// mod 12/02/02 from composite solutions from Oct and Nov runs
// #define KI_K1K2_DELAY_BIAS +40.599312

// JSH mod 11/16/2010 with data from Sept 2010 run: 
static Vector KI_Baseline_K1K2(51.702317,67.455618,-0.003674);
#define KI_K1K2_DELAY_BIAS +41.0430
