#define RMATRIX_H

#ifndef VECTORS_H
#include "Vector.h"
#endif


class RMatrix
{
private:
  double m[3][3];

public:
  RMatrix(const Vector basisX, const Vector basisY, const Vector basisZ);

  RMatrix(const double m11, const double m12, const double m13,
	  const double m21, const double m22, const double m23,
	  const double m31, const double m32, const double m33);

  RMatrix(void)
    {
      for (int i = 0; i < 3; i++)
	for (int j = 0; j < 3; j++)
	  m[i][j] = 0.0;
    }


  RMatrix transpose();

  double access(int i,int j) { return m[i][j];};

  RMatrix &operator*=(const RMatrix a) // Matrix product accumulation operator
  {
    double prod[3][3];

    for (int i = 0; i < 3; i++)
      for (int j = 0; j < 3; j++)
        {
	  prod[i][j] = 0.0;
	  for (int k = 0; k < 3; k++)
            prod[i][j] = m[i][k] * a.m[k][j];
	} // end i/j loops

    for (int i = 0; i < 3; i++)
      for (int j = 0; j < 3; j++)
        m[i][j] = prod[i][j];

    return (*this);

  } // end operator*=
  

  friend Vector operator^(const RMatrix M,const Vector V);


};
