#include <stdio.h>
#include <math.h>

/******************************************************************************/
/*                                                                            */
/*  check if the year "iyear" is a leap year                                  */
/*                                                                            */
/*  leap years    : 1600, 1984, 1988, 1992, 1996, 2000 etc.    (check = 0)    */
/*  no leap years : 1700, 1800, 1900, 2100 etc.                (check = 1)    */
/*                                                                            */
/******************************************************************************/

/******************************************************************************/
/*                                                                            */
/*  data fields : number of days per month                                    */
/*                                                                            */
/******************************************************************************/

    static int noleapyear[13] = {
        0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
    };

    static int leapyear[13] = {
        0, 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31  };


int ifLeapYear(int year)
{
  if ((year%100 == 0)
      && (year%400 != 0))
    return 0;
  else
    if (year%4 == 0)
      return 1;
    else
      return 0;
}



/******************************************************************************/
/*                                                                            */
/*  function calendar.c                          29Oct92      Manfred Bester  */
/*                                                                            */
/*  transforms format of calendar date                                        */
/*                                                                            */
/*                                                                            */
/*  input parameters :                                                        */
/*                                                                            */
/*   1.   year                         (---)    :  iyear                      */
/*   2.   day in the year              (---)    :  yearday                    */
/*                                                                            */
/*                                                                            */
/*  output parameters :                                                       */
/*                                                                            */
/*   1.   month                        (---)    :  month                      */
/*   2.   day                          (---)    :  day                        */
/*                                                                            */
/******************************************************************************/


int intoMonthDay(int iyear,int yearday,
		 int *pmonth,int *pday)
{
    int month, day, check;

    month = 0;
    if (ifLeapYear(iyear))
      {
        while (yearday > 0)
	  {
	    month++; 
	    yearday -= leapyear[month];
	  }
        day = yearday + leapyear[month];
      }
    else
      {
        while (yearday > 0)
	  {
	    month++;
	    yearday -= noleapyear[month];
	  } 
        day = yearday + noleapyear[month];
      }

    *pmonth = month;
    *pday   = day;

    return;
}


int yearDay(int iyear,int imonth,int iday)
{
  int i,yday = iday;

  for (i = 1; i < imonth; i++)
    if (ifLeapYear(iyear))
      yday += leapyear[i];
    else
      yday += noleapyear[i];

  return yday;
}
