/************************************************************************
*	Copyright (c) 1997-2001 California Institute of Technology      *
*                     U.S. Government Sponsorship                       *
* Under contract with the National Aeronautics and Space Administration *
*************************************************************************/


#define _COORDS_

/*
#ifndef _BASELINE_
#include "baseline.h"
#endif
*/

#ifndef _ANGLES_
#include "angles.h"
#endif

#ifndef VECTORS_H
#include "Vector.h"
#endif

#ifndef RMATRIX_H
#include "RMatrix.h"
#endif

#ifndef _NOVAS_
#include "novas.h"
#include "addNovas.h"
#endif

#ifndef _TIMEUTIL_
#include "timeUtil.h"
#endif

class coords
{
private:
  fk5_entry fk5pos;
  double RA, DEC, pmRA, pmDEC, PLX, rV;
  short int earth; // used in the solar system code to indicate which planet we are on
  double deltaT; // Difference TDT-UT1 at tjd in seconds

public:

  // Constructors
  coords()
    {
      RA = DEC = pmRA = pmDEC = PLX = 0;
    }



  coords(double ra, double dec, double pmRa = 0.0, double pmDec = 0.0,
	 double plx = 0.0, double epoch = 2000.0);

  coords(char *guiline);

  /************* Member functions ******************/ 

  // Inertial coordinate system

  Vector apparentPos(double jd);

  Vector topocentricPos(double jd, double latitude, double longitude, double altitude = 0.0);

  Vector virtualPos(double jd);

  Vector localPos(double jd, double latitude, double longitude, double altitude = 0.0);

  Vector barycentricPos(double jd);


  // Miscellaneous I/O 

  char *print(int pm = 0,int plx = 0);

  void hms(int *h, int *m, double *s);
  
  void dms(int *sign, int *d, int *m, double *s);

  double ra();

  double dec();

};

/****************** Utility Functions *****************/

double hmsToRad(int h, int m, double s);

double dmsToRad(int sign, int d, int m, double s);

char *threeVectorPrint(Vector vec);

Vector precessV(double jd1, double jd2, Vector arg);

Vector nutateMeanV(double jd, Vector arg);

Vector nutateTrueV(double jd, Vector arg);

void distance(double ra1, double dec1, double ra2, double dec2,
                double *deltara, double *deltadec);

