package KIyearDay;


require 5.000;

use Exporter();

@ISA = qw(Exporter);
@EXPORT = qw(yearDay);


#########################################################################
#     Interferometry Science Center (ISC) -- http://isc.caltech.edu     #
#	Copyright (c) 1997-2002 California Institute of Technology      #
#                     U.S. Government Sponsorship                       #
# Under contract with the National Aeronautics and Space Administration #
#########################################################################



##  check if the year "iyear" is a leap year                                  */
##                                                                            */
##  leap years    : 1600, 1984, 1988, 1992, 1996, 2000 etc.    (check = 0)    */
##  no leap years : 1700, 1800, 1900, 2100 etc.                (check = 1)    */

##  data fields : number of days per month                                    */

@noleapyear = (0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);

@leapyear = (0, 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);


sub ifLeapYear
{
    $year = shift @_;

    if (($year % 100 == 0)
	&& ($year % 400 != 0))
    {
	return 0;
    }
    else
    {
	if ($year % 4 == 0)
	{
	    return 1;
	}
	else
	{
	    return 0;
	}
    }

} #end ifLeapYear



## /******************************************************************************/
## /*                                                                            */
## /*  function calendar.c                          29Oct92      Manfred Bester  */
## /*                                                                            */
## /*  transforms format of calendar date                                        */
## /*                                                                            */
## /*                                                                            */
## /*  input parameters :                                                        */
## /*                                                                            */
## /*   1.   year                         (---)    :  iyear                      */
## /*   2.   day in the year              (---)    :  yearday                    */
## /*                                                                            */
## /*                                                                            */
## /*  output parameters :                                                       */
## /*                                                                            */
## /*   1.   month                        (---)    :  month                      */
## /*   2.   day                          (---)    :  day                        */
## /*                                                                            */
## /******************************************************************************/


sub intoMonthDay
{
    my $iyear = shift @_;
    my $yearday = shift @_;

    $month = 0;
    if (&ifLeapYear($iyear))
      {
	  while ($yearday > 0)
	  {
	      $month++; 
	      $yearday -= $leapyear[$month];
	  }
	  $day = $yearday + $leapyear[$month];
      }
    else
    {
        while ($yearday > 0)
	{
	    $month++;
	    $yearday -= $noleapyear[$month];
	} 
        $day = $yearday + $noleapyear[$month];
      }

} # end intoMonthDay



sub yearDay
{
    my $year = shift @_;
    my $month = shift @_;
    my $day = shift @_;

    my $yday = $day;

    for ($i = 1; $i < $month; $i++)
    {
	if (&ifLeapYear($year))
	{
	    $yday += $leapyear[$i];
	}
	else
	{
	    $yday += $noleapyear[$i];
	}

    } # end for loop

    return $yday;

} # end yearDay

sub daysInYear {
  my $year = shift @_;
  if(ifLeapYear($year)) {
    return 366;
  }
  return 365;
}

sub calcUTCDiff {
  my $year0 = shift @_;
  my $day0 = shift @_;
  my $year1 = shift @_;
  my $day1 = shift @_;
  my $neg = 0;

  if($year1 < $year0) {
    $neg = 1;
    my $tmp = $year1; $year1 = $year0; $year0 = $tmp;
    $tmp = day1; $day1 = $day0; $day0 = $tmp;
  } elsif($year1 == $year0) {
    if($day1 < $day0) {
      $neg = 1;
      my $tmp = $day1; $day1 = $day2; $day2 = $tmp;
    }
  }

  my $total = $day1;
  my $year = $year1;
  while($year > $year0) {
    $year -= 1;
    $total = daysInYear($year);
  };
  $total -= $day0;
  if($neg) {
    return (0-$total);
  }
  return $total;
}


1;
