package bsearch;



#########################################################################
#  hist_binary_search -- local to bsearch.c (A.B. 6/27/94)	        *
#									*
#  A.  Purpose:	The function binary_search executes a binary search     *
#       to determine the index of histogram bin that corresponds to     *
#       the input independent value.                                    *
#									*
#  B.  Background and use:						*
#									*
#  C.  Called by:							*
#									*
#  D.  Input/output files:						*
#									*
#  E.  Parameter description:						*
#	Input -								*
#        table - the (pointer to the) table of elements.  This table	*
#         is presumed to be in order of increasing values (float *).	*
#	 entries - the number of entries in the table (int).		*
#	 value - the value to be matched from a table entry (float).	*
#									*
#  F.  Detail function description:					*
#	      1.  Local Functions:					*
#	      2.  Externals:						*
#	      3.  Globals and Nonlocals used:				*
#	      4.  Global and Nonlocal variables modified:		*
#	      5.  Function flow is as follows:				*
#	      6.  Functions called by					*
#									*
#  G.  Function value: This function returns the index of the table	*
#	entry that most closely matches the input value.  If the input	*
#	value is either less than the minimum table value or greater	*
#	then the maximum table value, the index of the corresponding	*
#	extremum is returned (int).					*
#									*
#************************************************************************/
#**********  function declaration hist_binary_search  *******************/
sub hist_binary_search
{
##**********  local declarations hist_binary_search  *********************/
    my ($value,@table) = @_;
    my $entries = scalar @table;
    my ($lower,$middle,$upper);

#**********  begin hist_binary_search  **********************************/
    if ($value < $table[0])			## Handle the beyond extremes cases...	
    {
	return 0;
    }
    elsif ($value > $table[-1])
    {
	return ((scalar @table) - 1);
    }

    $lower = 0;					## Initialize the binary search pointers...	*/
    $upper = $entries - 1;
    while (($upper - $lower) > 1)		## Loop while we have a non-trivial search	*/
    {						##  interval...				*/
	$middle = int (($upper + $lower) / 2);	## Evaluate the interval midpoint...		*/
	if ($value > $table[$middle])		## Half the search interval appropriately... */
	{
	    $lower = $middle;
	}
	else
	{
	    $upper = $middle;
	}
    } ## end while

    if (($value - $table[$lower]) < ($table[$upper] - $value))	## Evaluate which end of the interval is	*/
    {
	return $lower; 						##  closer to the input value, and return	*/
    }
    else							##  the index of that end...			*/
    {
	return $upper;
    }
##*********  end hist_binary_search  ************************************/
}  ## end



return 1;
