#include "stdio.h"
#include "stdlib.h"
#include "novas.h"

#define N_STARS 3
#define N_TIMES 4

int main (void)
{
/*
   Main function to check out many parts of NOVAS-C by calling
   function 'topo_star' with 'solsys3.c'.
*/

   short int error = 0;
   short int earth = 3;
   short int i, j;

/*
   'deltat' is the difference in time scales, TT - UT1.

    The array 'tjd' contains four selected Julian dates at which the
    star positions will be evaluated.
*/

   double deltat = 60.0;
   double tjd[N_TIMES] = {2450203.5, 2450203.5, 2450417.5, 2450300.5};
   double ra, dec;

/*
   FK5 catalog data for three selected stars.
*/

   fk5_entry stars[N_STARS] = {
      {"POLARIS",   0, 2.5301955556, 89.2640888889, 19.8770,  -1.520,
               0.0070,-17.0, 2.020},
      {"Delta ORI", 0, 5.5334438889, -0.2991333333,  0.0100,  -0.220,
               0.0140, 16.0, 2.230},
      {"Theta CAR", 0,10.7159355556,-64.3944666667, -0.3480,   1.000,
               0.0000, 24.0, 2.760}};

/*
   The observer's terrestrial coordinates (latitude, longitude, height).
*/

   site_info geo_loc = {45.0, -75.0, 0.0};


/*
   Compute the topocentric places of the three stars at the four
   selected Julian dates.
*/

   for (i = 0; i < N_TIMES; i++)
   {
      for (j = 0; j < N_STARS; j++)
      {
         if (error = topo_star (tjd[i],earth,deltat,&stars[j],&geo_loc,
            &ra,&dec))
            printf ("Error %d from topo_star. Star %d  Time %d\n",
               error, j, i);
          else
         {
            printf ("JD = %f  Star = %s\n", tjd[i], stars[j].starname);
            printf ("RA = %16.13f  Dec = %16.12f\n", ra, dec);
            printf ("\n");
         }
      }
      printf ("\n");
   }

   exit (0);
}
